##  Writing Calculated Fields to Fact Sheets
Calculated fields are not automatically written to fact sheets. You can update fact sheets with calculated field values by implementing a code-based automation using APIs.
For example, you can set up a code-based automation to update custom fields on a fact sheet with calculated risk scores and map them to user-friendly, readable values. To learn how to implement this automation, see [Calculating Risk Scores and Updating a Fact Sheet Based on Survey Responses](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to set up an event-triggered automation that calculates the aggregated risk score for a fact sheet based on survey responses and updates this field on a fact sheet.").
